==> earth_osm-0.0.3.tar.gz: earth_osm-0.0.3/setup.py <==
"""Python setup.py for earth_osm package"""
import io
import os
from setuptools import find_packages, setup


def read(*paths, **kwargs):
    """Read the contents of a text file safely.
    >>> read("earth_osm", "VERSION")
    '0.1.0'
    >>> read("README.md")
    ...
    """

    content = ""
    with io.open(
        os.path.join(os.path.dirname(__file__), *paths),
        encoding=kwargs.get("encoding", "utf8"),
    ) as open_file:
        content = open_file.read().strip()
    return content


def read_requirements(path):
    path = os.path.abspath(path)
    return [
        line.strip()
        for line in read(path).split("\n")
        if not line.startswith(('"', "#", "-", "git+"))
    ]


setup(
    name="earth_osm",
    version=read("earth_osm", "VERSION"),
    description="Python tool to extract large-amounts of OpenStreetMap data",
    url="https://github.com/pypsa-meets-earth/earth-osm/",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="pypsa-meets-earth",
    packages=find_packages(exclude=["docs", "tests"]),
    install_requires=read_requirements("requirements.txt"),
    entry_points={
        "console_scripts": ["earth_osm = earth_osm.__main__:main"]
    },
    extras_require={"test": read_requirements("requirements-test.txt")},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
    ],
)

==> earth_osm-0.0.7.tar.gz: earth_osm-0.0.7/setup.py <==
"""Python setup.py for earth_osm package"""
import io
import os
from setuptools import find_packages, setup


def read(*paths, **kwargs):
    """Read the contents of a text file safely.
    >>> read("earth_osm", "VERSION")
    '0.1.0'
    >>> read("README.md")
    ...
    """
    content = ""
    with io.open(
        os.path.join(os.path.dirname(__file__), *paths),
        encoding=kwargs.get("encoding", "utf8"),
    ) as open_file:
        content = open_file.read().strip()
    return content


def read_reqs(name):
    return [line for line in read(name).split('\n') if line and not line.strip().startswith('#')]


setup(
    name="earth_osm",
    version=read("earth_osm", "VERSION"),
    description="Python tool to extract large-amounts of OpenStreetMap data",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="pypsa-meets-earth",
    url="https://github.com/pypsa-meets-earth/earth-osm/",
    packages=find_packages(exclude=["docs", "tests"]),
    include_package_data=True,
    python_requires=">=3.6",
    entry_points={
        "console_scripts": ["earth_osm = earth_osm.__main__:main"]
    },
    install_requires=read_reqs("requirements.txt"),
    extras_require={
    'test': read_reqs('requirements-test.txt'),
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
    ],
)
